/*******************************************************************************************
*
*   raylib [core] example - Basic window
*
*   Welcome to raylib!
*
*   To test examples in Notepad++, provided with default raylib installer package, 
*   just press F6 and run [raylib_compile_execute] script, it will compile and execute.
*   Note that compiled executable is placed in the same folder as .c file
*
*   You can find all basic examples on [C:\raylib\raylib\examples] directory and
*   raylib official webpage: [www.raylib.com]
* gcc -W -Wall -Wextra -Wno-unused-parameter -std=c99 core_basic_window.c -o core_basic_window
* Enjoy using raylib. :)
*
*   This example has been created using raylib 1.0 (www.raylib.com)
*   raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
*   Copyright (c) 2013-2020 Ramon Santamaria (@raysan5)
*
********************************************************************************************/
#include "raylib.h"
#include "air_defense.h"
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>


//----------------------------------------------------------------------------------
// Some Defines
//---------------------------------------------------------------------------------

#define NUMBER_MAX_OF_PARATROOPERS  150
#define NUMBER_OF_AIRCRAFTS  50
#define NUMBER_OF_BULLETS  50
#define NUMBER_OF_BOMBSHELLS 50
#define TROOPERS_PER_PLANE 15


//------------------------------------------------------------------------------------
// Global Variables Declaration
//------------------------------------------------------------------------------------

const int screenWidth = 1200;
const int screenHeight = 550;

static bool gameOver = false;
static bool pause =  false;
static int score = 0;

AntiParaCanon antiParaCanon;
AntiAircraftCanon antiAircraftCanon;
Paratrooper paraInitial;
Bombshell bombshellInit;
Bullet bulletInit;

Aircraft aircraft[NUMBER_OF_AIRCRAFTS];
Bullet bullet[NUMBER_OF_BULLETS];
Bombshell bombshells[NUMBER_OF_BOMBSHELLS];
Paratrooper paratroopers[NUMBER_MAX_OF_PARATROOPERS];

//------------------------------------------------------------------------------------
// Program main entry point
//------------------------------------------------------------------------------------

int main(void)
{
    // Initialization
    //--------------------------------------------------------------------------------------


    InitWindow(screenWidth, screenHeight, "raylib [core] example - basic window");

    SetTargetFPS(60);               // Set our game to run at 60 frames-per-second
    //--------------------------------------------------------------------------------------

    // Main game loop
    while (!WindowShouldClose())    // Detect window close button or ESC key
    {
        // Update
        //----------------------------------------------------------------------------------
        // TODO: Update your variables here
       // void UpdateGame(); 
        //----------------------------------------------------------------------------------

        // Draw
        //----------------------------------------------------------------------------------
        BeginDrawing();

            ClearBackground(SKYBLUE);

            DrawText("Congrats! You created your first window!", 190, 200, 20, SKYBLUE);

        EndDrawing();
        //----------------------------------------------------------------------------------
    }

    // De-Initialization
    //--------------------------------------------------------------------------------------
    //UnloadGame();
    CloseWindow();        // Close window and OpenGL context
    //--------------------------------------------------------------------------------------

    return 0;
}

void InitGame(void){

    //Initialize paratroopers
    paraInitial.speed.y = -2;
    paraInitial.speed.x = 0;
    paraInitial.color = RED;
    paraInitial.life = 2;
    paraInitial.hitbox.width = 10;
    paraInitial.hitbox.height = 10;
    paraInitial.droped = false;
    for (int k=0; k < NUMBER_MAX_OF_PARATROOPERS; k++){
            paratroopers[k] = paraInitial;
        }

    //Initialize aircrafts  
    for (int i = 0; i < NUMBER_OF_AIRCRAFTS; i++){
        aircraft[i].hitbox.width = 10;
        aircraft[i].hitbox.height = GetRandomValue(30,50);
        aircraft[i].numberOfParatroopers = GetRandomValue(0,TROOPERS_PER_PLANE);
        if (aircraft[i].hitbox.height<41){
            aircraft[i].hitbox.height = 30;
        }
        else{
            aircraft[i].hitbox.height = 50;
        }
        aircraft[i].hitbox.y = GetRandomValue(screenHeight/3, screenHeight - aircraft[i].hitbox.height);
        if (GetRandomValue(0,1)){
            aircraft[i].hitbox.x = -GetRandomValue(0,1000);
            aircraft[i].speed.x = 5;
            aircraft[i].xFirstToJump = GetRandomValue(10,screenHeight/2);
        }
        else{
            aircraft[i].speed.x = -5;
            aircraft[i].hitbox.x = -GetRandomValue(0,1000);
            aircraft[i].xFirstToJump = GetRandomValue(screenHeight/2,screenHeight-10);
        }
        aircraft[i].xLastTrooperDrop = -1;
        aircraft[i].speed.x = 5;
        aircraft[i].speed.y = 0;
        aircraft[i].color = BLACK;
    }

    //Initialize bombshells and bullets
    bombshellInit.radius = 5;
    bombshellInit.damageDone = 2;
    bombshellInit.sin = 0;
    bombshellInit.cos = 0;
    bombshellInit.ammoShot = false;
    bombshellInit.position.x = screenHeight;
    bombshellInit.position.y = 0;
    bombshellInit.speed.x = 0;
    bombshellInit.speed.y = 0;
    bombshellInit.color = RED;
    for (int j =0; j< NUMBER_OF_BOMBSHELLS;j++){
        bombshells[j] = bombshellInit;
    }

    bulletInit.radius = 1;
    bulletInit.damageDone = 2;
    bulletInit.sin = 0;
    bulletInit.cos = 0;
    bulletInit.ammoShot = false;
    bulletInit.position.x = 0;
    bulletInit.position.y = 0;
    bulletInit.speed.x = 0;
    bulletInit.speed.y = 0;
    bulletInit.color = RED;
    for (int j =0; j< NUMBER_OF_BULLETS;j++){
        bullet[j]= bulletInit;
    }

    //Initialize canons
    antiParaCanon.sin = 0.;
    antiParaCanon.cos = 0.;
    antiParaCanon.position.x = 0.;
    antiParaCanon.position.y = 0.;
    antiParaCanon.aimingPosition.x = 0.;
    antiParaCanon.aimingPosition.y = 0.;

    antiAircraftCanon.sin = 0.;
    antiAircraftCanon.cos = 0.;
    antiAircraftCanon.position.x = 0.;
    antiAircraftCanon.position.y = 0.;
    antiAircraftCanon.aimingPosition.x = 0.;
    antiAircraftCanon.aimingPosition.y = 0.;
}

void UpdateGame(void){
    if (!gameOver){
        if (!pause){
            //Releasing and animate Aircrafts

            //Defining where the canons are shooting

            antiParaCanon.aimingPosition = GetMousePosition();


            antiAircraftCanon.aimingPosition = GetMousePosition();

        }
    }
}

void DrawGame(void){}
